summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabbercapabilitiesmanager.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/protocols/jabber/jabbercapabilitiesmanager.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/protocols/jabber/jabbercapabilitiesmanager.h')
-rw-r--r--kopete/protocols/jabber/jabbercapabilitiesmanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/jabber/jabbercapabilitiesmanager.h b/kopete/protocols/jabber/jabbercapabilitiesmanager.h
index 8e2a95a6..f314d760 100644
--- a/kopete/protocols/jabber/jabbercapabilitiesmanager.h
+++ b/kopete/protocols/jabber/jabbercapabilitiesmanager.h
@@ -81,12 +81,12 @@ public slots:
/**
* Update if necessary the capabities for the JID passed in args.
* Caps are received in Presence messages so that's why we are
* passing a XMPP::Status object.
*
* @param jid JID that capabilities was updated.
* @param status The XMPP::Status that contain the caps.
*/
- void updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::Status &status);
+ void updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::tqStatus &status);
private slots:
/**
@@ -81,12 +81,12 @@ public slots:
* Update if necessary the capabities for the JID passed in args.
* Caps are received in Presence messages so that's why we are
- * passing a XMPP::Status object.
+ * passing a XMPP::tqStatus object.
*
* @param jid JID that capabilities was updated.
@@ -81,12 +81,12 @@ public slots:
*
* @param jid JID that capabilities was updated.
- * @param status The XMPP::Status that contain the caps.
+ * @param status The XMPP::tqStatus that contain the caps.
*/